@@ -2,11 +2,10 @@ package LWP::Protocol::PSGI;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use parent qw(LWP::Protocol);
 use HTTP::Message::PSGI qw( req_to_psgi res_from_psgi );
-use Guard;
 use Carp;
 
 my @protocols = qw( http https );
@@ -33,9 +32,9 @@ sub register {
     }
 
     if (defined wantarray) {
-        return guard {
+        return LWP::Protocol::PSGI::Guard->new(sub {
             $class->unregister_app($app);
-        };
+        });
     }
 }
 
@@ -91,6 +90,20 @@ sub handles {
     }
 }
 
+package
+  LWP::Protocol::PSGI::Guard;
+use strict;
+
+sub new {
+    my($class, $code) = @_;
+    bless $code, $class;
+}
+
+sub DESTROY {
+    my $self = shift;
+    $self->();
+}
+
 package
     LWP::Protocol::PSGI::App;
 use strict;
@@ -145,29 +158,29 @@ LWP::Protocol::PSGI - Override LWP's HTTP/HTTPS backend with your own PSGI appli
   use LWP::UserAgent;
   use LWP::Protocol::PSGI;
 
-  # can be Mojolicious, Catalyst, Dancer2 or any PSGI application
-  my $psgi_app = do {
+  # $app can be any PSGI application: Mojolicious, Catalyst or your own
+  my $app = do {
       use Dancer;
       set apphandler => 'PSGI';
       get '/search' => sub {
-          return 'googling ' . params->{q};
+          return 'searching for ' . params->{q};
       };
       dance;
   };
 
-  # Register the $psgi_app to handle all LWP requests
-  LWP::Protocol::PSGI->register($psgi_app);
+  # Register the $app to handle all LWP requests
+  LWP::Protocol::PSGI->register($app);
 
   # can hijack any code or module that uses LWP::UserAgent underneath, with no changes
   my $ua  = LWP::UserAgent->new;
   my $res = $ua->get("http://www.google.com/search?q=bar");
-  print $res->content; # "googling bar"
+  print $res->content; # "searching for bar"
 
   # Only hijacks specific host (and port)
   LWP::Protocol::PSGI->register($psgi_app, host => 'localhost:3000');
 
   my $ua = LWP::UserAgent->new;
-  $ua->get("http://localhost:3000/app"); # this routes $psgi_app
+  $ua->get("http://localhost:3000/app"); # this routes $app
   $ua->get("http://google.com/api");     # this doesn't - handled with actual HTTP requests
 
 =head1 DESCRIPTION
@@ -188,6 +201,43 @@ without modifying the calling code or its internals.
   my $mech = WWW::Mechanize->new;
   $mech->get("http://amazon.com/"); # $my_psgi_app runs
 
+=head1 TESTING
+
+This module is extremely handy if you have tests that run HTTP
+requests against your application and want them to work with both
+internal and external instances.
+
+  # in your .t file
+  use Test::More;
+  use LWP::UserAgent;
+
+  unless ($ENV{TEST_LIVE}) {
+      require LWP::Protocol::PSGI;
+      my $app = Plack::Util::load_psgi("app.psgi");
+      LWP::Protocol::PSGI->register($app);
+  }
+
+  my $ua = LWP::UserAgent->new;
+  my $res = $ua->get("http://myapp.example.com/");
+  is $res->code, 200;
+  like $res->content, qr/Hello/;
+
+This test script will by default route all HTTP requests to your own
+PSGI app defined in C<$app>, but with the environment variable
+C<TEST_LIVE> set, runs the requests against the live server.
+
+You can also combine L<Plack::App::Proxy> with L<LWP::Protocol::PSGI>
+to route all requests made in your test aginst a specific server.
+
+  use LWP::Protocol::PSGI;
+  use Plack::App::Proxy;
+
+  my $app = Plack::App::Proxy->new(remote => "http://testapp.local:3000")->to_app;
+  LWP::Protocol::PSGI->register($app);
+
+  my $ua = LWP::UserAgent->new;
+  my $res = $ua->request("http://testapp.com"); # this hits testapp.local:3000
+
 =head1 METHODS
 
 =over 4
@@ -198,7 +248,7 @@ without modifying the calling code or its internals.
   my $guard = LWP::Protocol::PSGI->register($app, %options);
 
 Registers an override hook to hijack HTTP requests. If called in a
-non-void context, returns a L<Guard> object that automatically resets
+non-void context, returns a guard object that automatically resets
 the override when it goes out of context.
 
   {
